#include <new>
#include "cx88_analog_driver_factory.h"
#include "cx88_cards.h"

#define CX88_ENABLE_ANALOG
#include "pchdtv_hd3000.h"
#include "pchdtv_hd5500.h"
#include "wintv_hvr1100.h"
#include "wintv_hvr4000.h"
#include "wintv_hvr1800.h"
#include "wintv_hvr1850.h"
#include "wintv_pci_fm.h"
#include "hdtv_wonder.h"
//#include "videomate_e800.h"

using namespace std;

cx88_analog_driver *cx88_analog_driver_factory::create(
   cx88_xml_config &cx88conf,
   tuner_config &tunerconf,
   const char *devnode,
   capvec &captures,
   cx88_analog_driver::cx88_analog_mode mode,
   cx88_analog_driver *slave,
   cx88_analog_driver *pip_driver,
   int &error)
{
   switch (get_card_id(tunerconf, devnode))
   {
      case CX88_CARD_ID_PCHDTV_HD3000:
         return (new(nothrow) pchdtv_hd3000(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_PCHDTV_HD5500:
         return (new(nothrow) pchdtv_hd5500(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_WINTV_HVR4000:
         return (new(nothrow) wintv_hvr4000(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_WINTV_HVR1100:
         return (new(nothrow) wintv_hvr1100(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_WINTV_HVR1800:
         return (new(nothrow) wintv_hvr1800(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_WINTV_HVR1850:
         return (new(nothrow) wintv_hvr1850(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_WINTV_PCI_FM:
         return (new(nothrow) wintv_pci_fm(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_HDTV_WONDER:
         return (new(nothrow) hdtv_wonder(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      //case CX88_CARD_ID_VIDEOMATE_E800:
      //   return (new(nothrow) videomate_e800(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      case CX88_CARD_ID_PIXELVIEW_XCAPTURE:
         return (new(nothrow) cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error));
      default:
         return NULL;
   }
}
